import React from "react";
import {FormProps, ModelForm, ModelInput} from "@rx-suite/ui";
import {observer} from "mobx-react-lite";
import {t} from "@lingui/macro";
import {SettingModel, SettingStore} from "../../stores/SettingStore";
import {LinearProgress} from "@material-ui/core";

export const SettingForm: React.FunctionComponent<FormProps> = observer(() => {
    const model = SettingStore.selectedModel as SettingModel;

    if (!model) {
        return <LinearProgress color={'secondary'}/>
    }

    return (
        <ModelForm model={model} suppressImportExport suppressMakeCopy>
            <ModelInput name={'max_dcs_trace_count'}
                        type={'number'}
                        inputProps={
                            {
                                min: 0,
                            }
                        }
                        hint={
                            {
                                title: t`Max DCS trace count`,
                                text: t`Maximum amount of trace logs that are kept per DCS connection, older traces are deleted first.`
                            }
                        }
            />
        </ModelForm>
    )
});